%define grassfix 72

%define _requires_exceptions nviz

Name:		grass
Version:	7.2.2
Release:	%mkrel 1
Group:		Sciences/Geosciences
Summary:	Geographic Resources Analysis Support System
License:	GPLv2+
URL:		http://grass.osgeo.org/
Source0:	http://grass.osgeo.org/grass%{grassfix}/source/grass-%{version}.tar.xz
Source2:	%{name}-config.h
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(libpng) 
BuildRequires:	pkgconfig(libtiff-4) 
BuildRequires:	pkgconfig(gdlib) >= 2.0 
BuildRequires:	freetype2-devel
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(glu) 
BuildRequires:	unixODBC-devel 
BuildRequires:	fftw-devel 
BuildRequires:	lesstif-devel
BuildRequires:	tk 
BuildRequires:	pkgconfig(tk)
BuildRequires:	pkgconfig(ncurses) 
BuildRequires:	pkgconfig(zlib) 
BuildRequires:	gdbm-devel 
BuildRequires:	readline-devel 
BuildRequires:	postgresql-devel
BuildRequires:	gcc-gfortran 
BuildRequires:	pkgconfig(gdal) 
BuildRequires:	flex
BuildRequires:	swig 
BuildRequires:	bison
BuildRequires:	pkgconfig(proj) 
BuildRequires:	proj >= 4.4.7
BuildRequires:	tcl 
BuildRequires:	pkgconfig(tcl)
BuildRequires:	fftw-devel
BuildRequires:  lapack-devel
BuildRequires:  blas-devel
BuildRequires:  libgomp-devel
BuildRequires:	pkgconfig(cfitsio)
BuildRequires:	unixODBC-devel
BuildRequires:	mysql-devel
BuildRequires:	termcap-devel
BuildRequires:	pkgconfig(python)
BuildRequires:	libwxPython-devel
BuildRequires:	pkgconfig(sqlite)
BuildRequires:  python-numpy
BuildRequires:	imagemagick
BuildRequires:	lzma

Requires:	xterm 
Requires:	tk 
Requires:	tcl
Requires:   wxPython

%description
GRASS (Geographic Resources Analysis Support System) is an 
open source, Free Software Geographical Information System (GIS)
with raster, topological vector, image processing, and graphics
production functionality that operates on various platforms 
through a graphical user interface and shell in X-Window.

%description -l de
GRASS (Geographic Resources Analysis Support System) ist Open Source
Free Software Geographische Informationssystem (GIS)mit Raster-, 
topologische Vektor-, Bild-Bearbeitung und Grafiken Funktionalitt. 
Das Produkt luft auf verschiedenen Plattformen mit einer grafische 
Benutzeroberflche und Shell in X-Window.


%define grass_devel %mklibname %name -d

%package -n %grass_devel

Summary:        Devel stuff for %name
Group:          Development/Libraries
Requires:       grass
Provides:       %name-devel = %{version}-%{release}

%description -n %grass_devel
This package contains header files needed if you wish to build applications
based on %name.

%prep
%setup -q 

%build
%define __cputoolize true
%define Werror_cflags %nil
%configure2_5x --host=%{_host} \
%if "%_lib" != "lib"
	--enable-64bit \
%endif
	--with-dbm-includes=%{_includedir}/gdbm/ \
	--with-postgres \
	--with-postgres-includes=%{_includedir}/ \
	--with-freetype \
	--with-freetype-includes=%{_includedir}/freetype2 \
	--with-motif \
	--with-cairo \
    --with-openmp \
	--with-lapack \
    --with-lapack-libs=%{_libdir} \
    --with-blas \
	--with-blas-libs=%{_libdir} \
    --with-opengl-libs=%{_libdir} \
	--with-motif-libs=%{_libdir} \
	--with-motif-libs=%{_libdir} \
	--with-motif-includes=%{_includedir} \
	--with-gdal  \
    --with-geos \
	--with-mysql --with-mysql-includes=%{_includedir}/mysql \
	--with-odbc \
	--enable-largefile \
	--with-curses \
	--with-python --with-wxwidgets="%{_bindir}/wx-config"\
	--with-sqlite \
	--with-cxx \
	--with-proj-share=%{_datadir}/proj \
	--with-nls \
	--with-readline

%make


%install
rm -rf %buildroot
%make_install \
	prefix=%{buildroot}%{_prefix} \
	UNIX_BIN=%{buildroot}%{_bindir}

# Change GISBASE in startup script
sed -i -e 's|%{buildroot}%{_prefix}/%{name}-%{version}|%{_libdir}/%{name}%{grassfix}|g' \
	%{buildroot}%{_bindir}/%{name}%{grassfix}

# Make libraries and headers available on the system
mv %{buildroot}%{_prefix}/%{name}-%{version}/lib %{buildroot}%{_libdir}
mv %{buildroot}%{_prefix}/%{name}-%{version}/include %{buildroot}%{_prefix}

rm -rf %{buildroot}%{_includedir}/Make/

mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 %{name}.pc %{buildroot}%{_libdir}/pkgconfig

# Create multilib header
install -p -m 644 %{buildroot}%{_includedir}/%{name}/config.h \
	%{buildroot}%{_includedir}/%{name}/config-%{cpuarch}.h
	
install -p -m 644 %{SOURCE2} %{buildroot}%{_includedir}/%{name}/config.h

# Make man pages available on the system, convert to utf8 and avoid name conflict
mkdir -p %{buildroot}%{_mandir}/man1
for man in $(ls %{buildroot}%{_prefix}/%{name}-%{version}/docs/man/man1/*.1)
do
	iconv -f iso8859-1 -t utf8 $man > %{buildroot}%{_mandir}/man1/$(basename $man)"%{name}"
done

rm -rf %{buildroot}%{_prefix}/%{name}-%{version}/docs/man

# Correct font path
sed -i -e 's|%{buildroot}%{_prefix}/%{name}-%{version}|%{_libdir}/%{name}%{grassfix}|' \
	%{buildroot}%{_prefix}/%{name}-%{version}/etc/fontcap

# Hide GISBASE into system's %%{_libdir} to be FHS compliant
mkdir -p %{buildroot}%{_libdir}/%{name}%{grassfix}
mv %{buildroot}%{_prefix}/%{name}-%{version}/{bin,driver,etc,fonts,gui,locale,scripts} \
	%{buildroot}%{_libdir}/%{name}%{grassfix}

# GRASS scripts expect docs in GISBASE
ln -s %{_docdir}/%{name} %{buildroot}%{_libdir}/%{name}%{grassfix}/docs

# rpm macro for version checking
mkdir -p %buildroot/usr/lib/rpm/macros.d
cat > %buildroot/usr/lib/rpm/macros.d/macros.%{name} <<EOF
# %name version is
%%%{name}_version %{version}
EOF

%__mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Grass
Comment=Geographic Resources Analysis Support System
Exec=/usr/bin/grass72 
Icon=%{name}
Terminal=true
Type=Application
Categories=X-MandrivaLinux-MoreApplications-Sciences-Geosciences;Science;Geology;
EOF

for i in {16,22,24,32,36,48,64,72,96,128,192}
do
  %__install -p -D dist.%{_target_platform}/gui/icons/%{name}-${i}x${i}.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}.png
done

%__mkdir %{buildroot}/%{_libdir}/grass%{grassfix}/locks
%__chmod 1777 %{buildroot}/%{_libdir}/grass%{grassfix}/locks

rm -rf %buildroot/grass-%version
rm -rf %buildroot/usr/grass-%version

%files
%{_bindir}/*
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/*/apps/*
%{_libdir}/%{name}%{grassfix}/
%{_mandir}/man1/*
%{_libdir}/%{name}%{grassfix}/docs

%doc AUTHORS COPYING GPL.TXT CHANGES
%{_libdir}/*.so
%{_libdir}/*.a

%files -n %grass_devel
%doc TODO doc/* SUBMITTING
/usr/lib/rpm/macros.d/macros.%{name}
%exclude %{_libdir}/*.a
%{_libdir}/pkgconfig/*
%{_libdir}/*[!%{version}].so
%{_includedir}/%{name}/

%changelog
* Tue Feb 06 2018 adrianomorselli <adrianomorselli> 7.2.2-1uplos2018
- new version
- new gcc
- build against new libreadline
